@@ -34,7 +34,6 @@ class WKFSAdapter:
         package_name: str = None,
         log_config: dict = None,
         access_token: str = None,
-        ezConfig: str = None,
     ) -> dict:
         """
         Call the `send` API for generating the document.
@@ -67,6 +66,7 @@ class WKFSAdapter:
         wkfs_id = self.wkfs_config["wkfs_id"]
         packages = self.wkfs_config["packages"]
         account_id = self.wkfs_config["account_id"]
+        ezConfig = self.wkfs_config["ezConfig"]
 
         wkfs_package_name = None
         wkfs_xml = None
@@ -119,7 +119,7 @@ class WKFSAdapter:
         request["transactionData"] = transaction_data_base64
         request["contentIdentifier"] = f"expere://{wkfs_id}/{wkfs_package}"
         if ezConfig is not None:
-            request["ezConfig"] = json.loads(ezConfig)
+            request["ezConfig"] = ezConfig
         generate["request"] = request
         payload["generate"] = generate
 
